"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Util_1 = require("../Util");
class Headers extends Map {
    set(key, value) {
        return super.set(key.toLocaleLowerCase(), value);
    }
    get(key) {
        return super.get(key.toLocaleLowerCase());
    }
}
class IncomingRequest {
    constructor(message) {
        this._headers = new Headers();
        this._url = message.url;
        this._method = message.method.toUpperCase();
        if ((0, Util_1.isCloudflareRequest)(message)) {
            message.headers.forEach((value, key) => {
                this._headers.set(key, value);
            });
        }
        else {
            for (const key in message.headers) {
                let value = message.headers[key];
                if (Array.isArray(value))
                    value = value.join(" ");
                this._headers.set(key, value);
            }
        }
    }
    get method() {
        return this._method;
    }
    get url() {
        return this._url;
    }
    get headers() {
        return this._headers;
    }
}
exports.default = IncomingRequest;
