/// <reference types="node" />
/// <reference types="./global.d.ts" />
/** /Engine/Context
 *
 * @author Alex Malotky
 */
import View, { RenderUpdate } from "../View";
import OutgoingResponse, { NodeResponse } from "./OutgoingResponse";
import IncomingRequest, { NodeRequeset } from "./IncomingRequest";
import Authorization from "../Authorization";
import { BodyData } from "../BodyParser";
export type { NodeRequeset, NodeResponse };
/** Context
 *
 * Wrapper Around Request/Response
 */
export default class Context {
    private _request;
    private _response;
    private _url;
    private _env;
    private _view;
    private _auth;
    private _form;
    private _search;
    private _params;
    /** Constructor
     *
     * @param request
     * @param response
     */
    constructor(request: NodeRequeset | Request, response: NodeResponse | undefined, data: BodyData, env: Env, view?: View, auth?: Authorization);
    /** Request Getter
     *
     */
    get request(): IncomingRequest;
    /** Response Getter
     *
     */
    get response(): OutgoingResponse;
    /** Form Data Getter
     *
     */
    get formData(): BodyData;
    /** Environment Getter
     *
     */
    get env(): Env;
    /** Url Getter
     *
     */
    get url(): URL;
    /** Method Getter
     *
     */
    get method(): string;
    /** Params Getter
     *
     */
    get params(): Map<string, string>;
    /** Search Getter
     *
     */
    get search(): Map<string, string>;
    /** Set Status Code
     *
     * @param {number} value
     * @returns {this}
     */
    status(value: number): this;
    /** Write Chunk to Response
     *
     * @param {any} chunk
     * @returns {this}
     */
    write(chunk: any): this;
    /** End Response
     *
     */
    end(): void;
    /** Set Json Content
     *
     * @param {Object} object
     * @returns {this}
     */
    json(object: Object): this;
    /** Set Text Content
     *
     * @param {string} value
     * @returns {this}
     */
    text(value: string): this;
    /** Set HTML Content
     *
     * @param {string} value
     * @returns {this}
     */
    html(value: string): Context;
    /** Expects Render
     *
     * Checks headers to test if request is expecting render object.
     *
     * @returns {boolean}
     */
    expectsRender(): boolean;
    /** Reunder Update Content
     *
     * @param {ContentUpdate} value
     */
    render(value: RenderUpdate): void;
    /** Flush Update Content
     *
     */
    flush(): Promise<Response | undefined>;
    /** Get Authorization
     *
     * @returns {Promise<User|null>}
     */
    getAuth(): Promise<User | null>;
    setAuth(user: User | null): Promise<void>;
    /** Redirect
     *
     * @param url
     * @param status
     */
    redirect(url: string | URL, status?: number): void;
}
