/** /Engine/Routing/Layer.ts
 *
 * @author Alex Malotky
 */
import Context from "../Context";
import Layer, { Middleware } from "./Layer";
/** Method Stack
 *
 */
declare class Stack extends Array<{
    name: string;
    layer: Layer;
}> {
    /** Add Method Layer
     *
     * @param {string} name
     * @param {Layer} layer
     */
    add(name: string, layer: Layer): void;
}
/** Router
 *
 */
export default class Router extends Layer {
    protected _methods: Stack;
    /** Constructor
     *
     * @param {any} options
     */
    constructor(path?: string);
    /** Handle Request Override
     *
     * @param {Context} context
     */
    handle(context: Context): Promise<void>;
    private _filter;
    /** Use Middleware Method
     *
     */
    use(middleware: Middleware | Router): void;
    /** Get Method
     *
     * @param {string} path
     * @param {EndPoint} handler
     * @returns {Router}
     */
    get(handler: Middleware): Router;
    get(path: string, handler: Middleware): Router;
    /** Head Method
     *
     * @param {string} path
     * @param {EndPoint} handler
     * @returns {Router}
     */
    head(handler: Middleware): Router;
    head(path: string, handler: Middleware): Router;
    /** Post Method
     *
     * @param {string} path
     * @param {EndPoint} handler
     * @returns {Router}
     */
    post(handler: Middleware): Router;
    post(path: string, handler: Middleware): Router;
    /** Put Method
     *
     * @param {string} path
     * @param {EndPoint} handler
     * @returns {Router}
     */
    put(handler: Middleware): Router;
    put(path: string, handler: Middleware): Router;
    /** Delete Method
     *
     * @param {string} path
     * @param {EndPoint} handler
     * @returns {Router}
     */
    delete(handler: Middleware): Router;
    delete(path: string, handler: Middleware): Router;
    /** Options Method
     *
     * @param {string} path
     * @param {EndPoint} handler
     * @returns {Router}
     */
    options(handler: Middleware): Router;
    options(path: string, handler: Middleware): Router;
    /** Patch Method
     *
     * @param {string} path
     * @param {EndPoint} handler
     * @returns {Router}
     */
    patch(handler: Middleware): Router;
    patch(path: string, handler: Middleware): Router;
    /** All Method
     *
     * @param {string} path
     * @param {EndPoint} handler
     * @returns {Router}
     */
    all(handler: Middleware): Router;
    all(path: string, handler: Middleware): Router;
}
export {};
