"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Layer_1 = __importDefault(require("./Layer"));
const Util_1 = require("../Util");
const ROUTER_ERROR = () => { throw new Error("_handler called from Router!"); };
/** Method Stack
 *
 */
class Stack extends Array {
    /** Add Method Layer
     *
     * @param {string} name
     * @param {Layer} layer
     */
    add(name, layer) {
        this.push({ name, layer });
    }
}
/** Router
 *
 */
class Router extends Layer_1.default {
    /** Constructor
     *
     * @param {any} options
     */
    constructor(path = "/") {
        super(path, { end: false }, ROUTER_ERROR);
        this._methods = new Stack();
    }
    /** Handle Request Override
     *
     * @param {Context} context
     */
    async handle(context) {
        if (this.match(context)) {
            for (const { name, layer } of this._methods) {
                if (name === "MIDDLEWARE") {
                    await layer.handle(context);
                    if (context.response.commited())
                        return;
                }
                else if (name === context.method || name === "ALL") {
                    await layer.handle(context);
                    if (context.response.commited())
                        return;
                }
            }
        }
    }
    _filter(args) {
        switch (typeof args[0]) {
            case "object":
                args[0].prefix(this.path);
                return args[0];
            case "function":
                const l = new Layer_1.default("/", args[0]);
                l.prefix(this.path);
                return l;
            case "string":
                switch (typeof args[1]) {
                    case "function":
                        const l = new Layer_1.default(args[0], args[1]);
                        l.prefix(this.path);
                        return l;
                    case "object":
                        args[1].path = (0, Util_1.joinPath)(args[0], args[1].path);
                        args[1].prefix(this.path);
                        return args[1];
                    default:
                        throw new TypeError("Middlware must be a function or Layer!");
                }
            default:
                throw new TypeError("Path must be a string!");
        }
    }
    /** Use Middleware Method
     *
     */
    use(middleware) {
        switch (typeof middleware) {
            case "function":
                this._methods.add("MIDDLEWARE", new Layer_1.default("*", middleware));
                break;
            case "object":
                if (middleware instanceof Router) {
                    this._methods.add("MIDDLEWARE", middleware);
                    break;
                }
            default:
                throw new TypeError("Invalid middleware!");
        }
    }
    get() {
        this._methods.add("GET", this._filter(arguments));
        return this;
    }
    head() {
        this._methods.add("HEAD", this._filter(arguments));
        return this;
    }
    post() {
        this._methods.add("POST", this._filter(arguments));
        return this;
    }
    put() {
        this._methods.add("PUT", this._filter(arguments));
        return this;
    }
    delete() {
        this._methods.add("DELETE", this._filter(arguments));
        return this;
    }
    options() {
        this._methods.add("OPTIONS", this._filter(arguments));
        return this;
    }
    patch() {
        this._methods.add("PATCH", this._filter(arguments));
        return this;
    }
    all() {
        this._methods.add("ALL", this._filter(arguments));
        return this;
    }
}
exports.default = Router;
