"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Router_1 = __importDefault(require("./Router"));
const HttpError_1 = __importDefault(require("../HttpError"));
class Routing extends Router_1.default {
    /** Routing Constructor
     *
     */
    constructor() {
        super("");
        this.notFoundHandler = (ctx) => { throw new HttpError_1.default(404, `${ctx.url.pathname} was not found!`); };
        this.errorHandler = (e, ctx) => {
            ctx.status(e.statusCode || e.code || e.status || 500).write(e.message || String(e)).end();
        };
    }
    /** Routing Wrappper
     *
     * @param {Context} context
     * @param {any} error
     * @returns {Promise<Response>}
     */
    async route(context, error) {
        try {
            if (error)
                throw error;
            await this.handle(context);
        }
        catch (e) {
            await this.errorHandler(e, context);
        }
        return await context.flush();
    }
    /** Handle Routing
     *
     * @param {Context} context
     * @returns {Promise<void>}
     */
    async handle(context) {
        try {
            for (const { name, layer } of this._methods) {
                if (name === "MIDDLEWARE") {
                    await layer.handle(context);
                    if (context.response.commited())
                        return;
                }
                else if (name === context.method || name === "ALL") {
                    await layer.handle(context);
                    if (context.response.commited())
                        return;
                }
            }
            await this.notFoundHandler(context);
        }
        catch (route_err) {
            if (route_err === 404 || route_err.code === 404 || route_err.status === 404) {
                await this.notFoundHandler(context);
            }
            else {
                throw route_err;
            }
        }
    }
    /** Not Found Handler Setter
     *
     * @param {Handler} handler
     */
    notFound(handler) {
        if (typeof handler !== "function")
            throw new TypeError("Not Found Handler must be a function!");
        this.notFoundHandler = handler;
    }
    /** Error Handler Setter
     *
     * @param {ErrorHandler} handler
     */
    error(handler) {
        if (typeof handler !== "function")
            throw new TypeError("Error Handler must be a function!");
        this.errorHandler = handler;
    }
}
exports.default = Routing;
