/// <reference types="./global.d.ts" />
/** /Engine/View/Html/Head
 *
 * @author Alex Malotky
 */
import HTMLElement from "..";
import HeadAttributes from "../Element/Head";
import { TitleInit, TitleUpdate } from "./Title";
import { BaseInit } from "./Base";
import { LinkInit, LinkUpdate } from "./Link";
import { StyleInit, StyleUpdate } from "./Style";
import { ScriptInit, ScriptUpdate } from "./Script";
import { MetaInit, MetaUpdate } from "./Meta";
export interface HeadInit {
    base?: BaseInit;
    title?: TitleInit;
    meta?: Array<MetaInit>;
    links?: Array<LinkInit>;
    styles?: Array<StyleInit>;
    scripts?: Array<ScriptInit>;
}
export interface HeadUpdate {
    title?: TitleUpdate;
    links?: Dictionary<LinkUpdate>;
    meta?: Dictionary<MetaUpdate>;
    styles?: Dictionary<StyleUpdate> | string;
    scripts?: Dictionary<ScriptUpdate>;
}
/** Merge Init With Update
 *
 * @param {HeadInit} init
 * @param {HeadUpdate} update
 * @returns {HeadInit}
 */
export declare function mergeUpdateToInit(init: HeadInit, update?: HeadUpdate): HeadInit;
/** Merge Init With Update
 *
 * @param {HeadInit} init
 * @param {HeadUpdate} update
 * @returns {HeadInit}
 */
export declare function mergeUpdateToUpdate(init: HeadInit, update?: HeadUpdate): HeadUpdate;
/** Head Tag
 *
 * https://developer.mozilla.org/en-US/docs/Web/HTML/Element/head
 * @param {HeadInit} init
 * @returns {HTMLContent}
 */
export default function Head(init: HeadInit, att?: HeadAttributes): HTMLElement;
