/// <reference types="./global.d.ts" />
/** /Engine/View
 *
 * @author Alex Malotky
 */
import { HTMLInit } from "./Html";
import Content from "./Html/Content";
import { HeadInit, HeadUpdate } from "./Html/Head";
import Context from "../Context";
export type RenderFunction = (update: Dictionary<Content>) => Content;
export interface RenderUpdate {
    head?: HeadUpdate;
    body?: Dictionary<Content>;
    redirect?: string;
    update?: Dictionary<Content>;
}
export interface FetchUpdate {
    head: HeadUpdate;
    body?: Dictionary<string>;
    redirect?: string;
    update?: Dictionary<string>;
}
/** View Class
 *
 */
export default class View {
    #private;
    static readonly injectFilePath = "/zim.js";
    private static readonly injectedFileRoute;
    private static readonly injectedFileType;
    private static readonly injectedFileContent;
    static injectFile(ctx: Context): void;
    /** Constructor
     *
     * @param {Array<ElementTag>} headTags
     * @param {RenderFunction} stationaryContent
     * @param {AttributeList} attributes
     */
    constructor(attributes?: HTMLInit, headInit?: HeadInit, renderContent?: RenderFunction);
    /** Render Content
     *
     * @param {RenderUpdate} update
     * @returns {string}
     */
    render(update: RenderUpdate): string;
    /** Update Content
     *
     * @param {RenderUpdate} update
     * @returns {FetchUpdate}
     */
    update(value: RenderUpdate): FetchUpdate;
}
