"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Authorization = exports.View = exports.HttpError = exports.createElement = exports.Context = exports.Router = void 0;
/** /Engine
 *
 * @author Alex Malotky
 */
const Routing_1 = __importDefault(require("./Routing"));
const Layer_1 = __importDefault(require("./Routing/Layer"));
const Context_1 = __importDefault(require("./Context"));
exports.Context = Context_1.default;
const View_1 = __importDefault(require("./View"));
exports.View = View_1.default;
const Authorization_1 = __importDefault(require("./Authorization"));
exports.Authorization = Authorization_1.default;
const Util_1 = require("./Util");
//Exports
const Router_1 = __importDefault(require("./Routing/Router"));
exports.Router = Router_1.default;
const Element_1 = require("./View/Html/Element");
Object.defineProperty(exports, "createElement", { enumerable: true, get: function () { return Element_1.createElement; } });
const HttpError_1 = __importDefault(require("./HttpError"));
exports.HttpError = HttpError_1.default;
const BodyParser_1 = __importDefault(require("./BodyParser"));
class Engine extends Routing_1.default {
    constructor() {
        super();
        this._env = {};
    }
    /** View Setter
     *
     * @param {View} value
     */
    view(value) {
        if (!(value instanceof View_1.default))
            throw new Error("Value must be an instance of View!");
        if (this._methods.length === 0 || this._methods.at(0).layer.path !== View_1.default.injectFilePath) {
            this._methods.unshift({
                name: "ALL",
                layer: new Layer_1.default(View_1.default.injectFilePath, View_1.default.injectFile)
            });
        }
        this._view = value;
    }
    /** Auth Setter
     *
     * @param {View} value
     */
    auth(value) {
        if (!(value instanceof Authorization_1.default))
            throw new TypeError("Value must be an instance of Authorization!");
        if (typeof value.get() !== "function")
            throw new TypeError("Authentication Getter is not set!");
        this._auth = value;
    }
    env(key, value) {
        if ((0, Util_1.inCloudfareWorker)())
            throw new Error("Cannot setup envrionment in cloudflare worker!");
        this._env[key] = value;
    }
    async fetch(req, env) {
        if (env.ASSETS) {
            const assetResponse = await env.ASSETS.fetch(req.clone());
            if (assetResponse.status < 400)
                return assetResponse;
        }
        return (await this.start(req, undefined, env));
    }
    get server() {
        return async (req, res) => await this.start(req, res);
    }
    async start(req, res, env) {
        let error;
        let body = await (0, BodyParser_1.default)(req);
        if (body instanceof Error) {
            error = body;
            body = new Map();
        }
        const context = new Context_1.default(req, res, body, env || this._env, this._view, this._auth);
        return await this.route(context, error);
    }
    use() {
        switch (arguments.length) {
            case 0:
                throw new Error("No arguments were passed to Engine.use!");
            case 1:
                switch (typeof arguments[0]) {
                    case "function":
                        super.use(arguments[0]);
                        break;
                    case "object":
                        this._methods.add("ALL", arguments[0]);
                        break;
                    default:
                        throw new Error("Handler must be a function or a Layer!");
                }
                break;
            default:
                switch (typeof arguments[1]) {
                    case "function":
                    case "object":
                        super.all(arguments[0], arguments[1]);
                        break;
                    default:
                        throw new Error("Handler must be a function or a Layer!");
                }
        }
    }
}
exports.default = Engine;
